var tutorials =
[
    [ "Guide to building OGRE", "building-ogre.html", null ],
    [ "Setting up an OGRE project", "setup.html", [
      [ "CMake Configuration", "setup.html#cmake", null ],
      [ "Application skeleton", "setup.html#skeleton", null ]
    ] ],
    [ "Your First Scene", "tut__first_scene.html", [
      [ "How Ogre Works", "tut__first_scene.html#howogreworks", [
        [ "SceneManager", "tut__first_scene.html#scenemanager", null ],
        [ "SceneNode", "tut__first_scene.html#SceneNode", null ],
        [ "Entity", "tut__first_scene.html#Entity", null ]
      ] ],
      [ "Setting Up the Scene", "tut__first_scene.html#SettingUptheScene", null ],
      [ "Coordinates Systems", "tut__first_scene.html#CoordinatesSystems", null ],
      [ "Adding Another Entity", "tut__first_scene.html#AddingAnotherEntity", null ],
      [ "More About Entities", "tut__first_scene.html#MoreAboutEntities", null ],
      [ "More About SceneNodes", "tut__first_scene.html#MoreAboutSceneNodes", null ],
      [ "Changing An Entity's Scale", "tut__first_scene.html#ChangingAnEntitysScale", null ],
      [ "Rotating An Entity", "tut__first_scene.html#RotatingAnEntity", null ],
      [ "The Ogre Environment", "tut__first_scene.html#TheOgreEnvironment", [
        [ "Libraries and Plugins", "tut__first_scene.html#LibrariesandPlugins", null ],
        [ "Configuration Files", "tut__first_scene.html#ConfigurationFiles", null ]
      ] ],
      [ "Conclusion", "tut__first_scene.html#Conclusion1", null ]
    ] ],
    [ "Lights, Cameras, and Shadows", "tut__lights_cameras_shadows.html", [
      [ "The Ogre Camera Class", "tut__lights_cameras_shadows.html#bt2TheOgreCameraClass", null ],
      [ "Creating a Camera", "tut__lights_cameras_shadows.html#bt2CreatingaCamera", null ],
      [ "Viewports", "tut__lights_cameras_shadows.html#bt2Viewports", null ],
      [ "Creating a Viewport", "tut__lights_cameras_shadows.html#bt2CreatingaViewport", null ],
      [ "Building the Scene", "tut__lights_cameras_shadows.html#bt2BuildingtheScene", null ],
      [ "Using Shadows in Ogre", "tut__lights_cameras_shadows.html#bt2UsingShadowsinOgre", null ],
      [ "Lights", "tut__lights_cameras_shadows.html#bt2Lights", null ],
      [ "Creating a Light", "tut__lights_cameras_shadows.html#CreatingaLight", null ],
      [ "Creating More Lights", "tut__lights_cameras_shadows.html#CreatingMoreLights", null ],
      [ "Shadow Types", "tut__lights_cameras_shadows.html#ShadowTypes", null ],
      [ "Conclusion", "tut__lights_cameras_shadows.html#Conclusion2", null ]
    ] ],
    [ "Terrain, Sky and Fog", "tut__terrain_sky_fog.html", [
      [ "An Introduction to Terrain", "tut__terrain_sky_fog.html#tut_terrain", [
        [ "Terrain loading overview", "tut__terrain_sky_fog.html#bt3Overview", null ],
        [ "Terrain appearance", "tut__terrain_sky_fog.html#bt3Appearance", null ],
        [ "Defining a terrain chunk", "tut__terrain_sky_fog.html#bt3TerrainChunk", null ],
        [ "Loading a heightmap", "tut__terrain_sky_fog.html#bt3Heightmap", null ],
        [ "Height based blending", "tut__terrain_sky_fog.html#bt3Blendmap", null ],
        [ "Terrain Loading Label", "tut__terrain_sky_fog.html#bt3LoadingLabel", null ]
      ] ],
      [ "Simulating a sky", "tut__terrain_sky_fog.html#bt3sky", null ],
      [ "Fog", "tut__terrain_sky_fog.html#tut_fog", null ],
      [ "Conclusion", "tut__terrain_sky_fog.html#conclusion3", null ]
    ] ],
    [ "Working with NumPy", "working-with-numpy.html", null ],
    [ "Trays GUI System", "trays.html", [
      [ "Trays", "trays.html#trays-1", null ],
      [ "TrayManager", "trays.html#traymanager", null ],
      [ "Widgets", "trays.html#widgets", null ],
      [ "Special Widgets", "trays.html#special-widgets", null ],
      [ "TrayListener", "trays.html#tray-listener", null ],
      [ "Things to Try", "trays.html#things-to-try", null ]
    ] ],
    [ "Volume Component", "volume.html", [
      [ "How to use it", "volume.html#howto", null ],
      [ "Manual creation of a CSG-Tree", "volume.html#creation", null ],
      [ "Getting the triangles of the chunks", "volume.html#triangles", null ],
      [ "Intersecting a ray with a volume", "volume.html#intersecting", null ],
      [ "Editing a Volume made from a GridSource", "volume.html#editing", null ]
    ] ],
    [ "Manual mesh creation", "manual-mesh-creation.html", null ],
    [ "Using the Profiler", "profiler.html", [
      [ "Reading the Display", "profiler.html#profRead", null ],
      [ "Features", "profiler.html#profFeatures", null ],
      [ "Performance and Accuracy", "profiler.html#profAccuracy", null ],
      [ "Remotery Backend", "profiler.html#profRemotery", null ],
      [ "Release Version Considerations", "profiler.html#profRelmode", null ]
    ] ],
    [ "External Texture Sources", "_external-_texture-_sources.html", null ],
    [ "Shadow Mapping in Ogre", "_shadow_mapping_ogre.html", [
      [ "Introduction to the Shadow Mapping Algorithm", "_shadow_mapping_ogre.html#ShadowMappingIntro", [
        [ "Formalism", "_shadow_mapping_ogre.html#sm_formalism", null ],
        [ "Depth Biasing", "_shadow_mapping_ogre.html#DepthBias", null ],
        [ "Percentage Closest Filtering", "_shadow_mapping_ogre.html#sm_pcm", null ]
      ] ],
      [ "Variants", "_shadow_mapping_ogre.html#sm_variants", [
        [ "Storing Additional Info", "_shadow_mapping_ogre.html#sm_additional_info", null ],
        [ "Breaking up Shadow Frusta", "_shadow_mapping_ogre.html#sm_breaking_frusta", null ],
        [ "Playing with Projection Matrices", "_shadow_mapping_ogre.html#sect_planeopt", null ]
      ] ],
      [ "Theory and Analysis", "_shadow_mapping_ogre.html#sm_theory", [
        [ "(Non)Optimality of Logarithmic Shadow Maps", "_shadow_mapping_ogre.html#sm_nonopt", null ],
        [ "Sampling Aliasing versus Depth Precision Aliasing", "_shadow_mapping_ogre.html#sm_aliasing", null ],
        [ "Projective versus Perspective Aliasing", "_shadow_mapping_ogre.html#sm_proj_aliasing", null ]
      ] ],
      [ "Implementation", "_shadow_mapping_ogre.html#Implementation", null ]
    ] ],
    [ "Deferred Shading", "deferred.html", [
      [ "What is Deferred Shading?", "deferred.html#what", null ],
      [ "Creating the G-Buffer", "deferred.html#creating", null ],
      [ "Lighting the scene", "deferred.html#lighting", [
        [ "Rendering the light geometry", "deferred.html#lightgeom", null ]
      ] ],
      [ "Post Processing", "deferred.html#post", null ],
      [ "Integration in real projects", "deferred.html#realprojects", null ],
      [ "Summary", "deferred.html#summary", [
        [ "Further reading", "deferred.html#further", null ]
      ] ]
    ] ],
    [ "Using the PCZ Scene Manager", "pczscenemanager.html", null ]
];